==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/codedeploy/LambdaDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * (experimental) A custom Deployment Configuration for a Lambda Deployment Group.
 * <p>
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom Lambda Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {&#64;link Construct}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:10.335Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.LambdaDeploymentConfig")
public class LambdaDeploymentConfig extends software.amazon.jsii.JsiiObject {

    protected LambdaDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_10_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_10MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_15_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_15MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_30_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_30MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_5_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_5MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_10_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_10MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_1_MINUTE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_1MINUTE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_2_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_2MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_3_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_3MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
    }

    /**
     * (experimental) Import a custom Deployment Configuration for a Lambda Deployment Group defined outside the CDK.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param _scope the parent Construct for this new Construct. This parameter is required.
     * @param _id the logical ID of this new Construct. This parameter is required.
     * @param props the properties of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig doImport(final @org.jetbrains.annotations.NotNull software.constructs.Construct _scope, final @org.jetbrains.annotations.NotNull java.lang.String _id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfigImportProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "import", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(_scope, "_scope is required"), java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig ALL_AT_ONCE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_10_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_15_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_30_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_5_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_10_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_1_MINUTE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_2_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_3_MINUTES;
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/codedeploy/LambdaDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for a Lambda Deployment Group.
 * <p>
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom Lambda Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {&#64;link Construct}
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * LambdaApplication myApplication;
 * Function func;
 * Version version = func.addVersion("1");
 * Alias version1Alias = Alias.Builder.create(this, "alias")
 *         .aliasName("prod")
 *         .version(version)
 *         .build();
 * LambdaDeploymentGroup deploymentGroup = LambdaDeploymentGroup.Builder.create(this, "BlueGreenDeployment")
 *         .application(myApplication) // optional property: one will be created for you if not provided
 *         .alias(version1Alias)
 *         .deploymentConfig(LambdaDeploymentConfig.LINEAR_10PERCENT_EVERY_1MINUTE)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.337Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.LambdaDeploymentConfig")
public class LambdaDeploymentConfig extends software.amazon.jsii.JsiiObject {

    protected LambdaDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_10_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_10MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_15_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_15MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_30_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_30MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        CANARY_10_PERCENT_5_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "CANARY_10PERCENT_5MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_10_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_10MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_1_MINUTE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_1MINUTE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_2_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_2MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
        LINEAR_10_PERCENT_EVERY_3_MINUTES = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "LINEAR_10PERCENT_EVERY_3MINUTES", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class));
    }

    /**
     * Import a custom Deployment Configuration for a Lambda Deployment Group defined outside the CDK.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param _scope the parent Construct for this new Construct. This parameter is required.
     * @param _id the logical ID of this new Construct. This parameter is required.
     * @param props the properties of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig doImport(final @org.jetbrains.annotations.NotNull software.constructs.Construct _scope, final @org.jetbrains.annotations.NotNull java.lang.String _id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfigImportProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.LambdaDeploymentConfig.class, "import", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(_scope, "_scope is required"), java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig ALL_AT_ONCE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_10_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_15_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_30_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig CANARY_10_PERCENT_5_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_10_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_1_MINUTE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_2_MINUTES;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig LINEAR_10_PERCENT_EVERY_3_MINUTES;
}
